@@ -17,7 +17,7 @@ logging.basicConfig(
 
 
 class DBConnect:
-    def __init__(self, db: str, collection: str, home_key='MONGODB_HOST', port_key='MONGODB_PORT', home_key):
+    def __init__(self, db: str, collection: str, home_key='MONGODB_HOST', port_key='MONGODB_PORT'):
         self.mongo_home = os.environ.get(home_key, None)
         self.mongo_port = os.environ.get(port_key, None)
 
